@@ -36,7 +36,7 @@ from rqalpha.utils import INST_TYPE_IN_STOCK_ACCOUNT
 from rqalpha.utils.logger import user_system_log
 from rqalpha.const import DAYS_CNT
 from rqalpha.api import export_as_api
-
+from .plot.utils import max_ddd as _max_ddd
 from .plot_store import PlotStore
 
 
@@ -305,6 +305,7 @@ class AnalyserMod(AbstractMod):
                 summary["benchmark_symbol"] = self._env.data_proxy.instrument(benchmark_obid).symbol
             else:
                 summary["benchmark"] = ",".join(f"{o}:{w}" for o, w in self._benchmark)
+                summary["benchmark_symbol"] = ",".join(f"{self._env.data_proxy.instrument(o).symbol}:{w}" for o, w in self._benchmark)
 
         risk_free_rate = data_proxy.get_risk_free_rate(self._env.config.base.start_date, self._env.config.base.end_date)
         risk = Risk(
@@ -357,6 +358,16 @@ class AnalyserMod(AbstractMod):
         total_portfolios = df.set_index('date').sort_index()
         weekly_nav = df.resample("W", on="date").last().set_index("date").unit_net_value.dropna()
         weekly_returns = (weekly_nav / weekly_nav.shift(1).fillna(1)).fillna(0) - 1
+
+        # 最长回撤持续期
+        max_ddd = _max_ddd(total_portfolios.unit_net_value.values, total_portfolios.index)
+        summary["max_drawdown_duration"] = max_ddd
+        summary.update({
+            "max_drawdown_duration_start_date": str(max_ddd.start_date),
+            "max_drawdown_duration_end_date": str(max_ddd.end_date),
+            "max_drawdown_duration_days": (max_ddd.end_date - max_ddd.start_date).days,
+        })
+
         result_dict = {
             'summary': summary,
             'trades': trades,
@@ -383,6 +394,13 @@ class AnalyserMod(AbstractMod):
             weekly_b_nav = df.resample("W", on="date").last().set_index("date").unit_net_value.dropna()
             weekly_b_returns = (weekly_b_nav / weekly_b_nav.shift(1).fillna(1)).fillna(0) - 1
             result_dict['benchmark_portfolio'] = benchmark_portfolios
+            # 超额收益最长回撤持续期
+            ex_returns = total_portfolios.unit_net_value - benchmark_portfolios.unit_net_value
+            max_ddd = _max_ddd(ex_returns + 1, total_portfolios.index)
+            result_dict["summary"]["excess_max_drawdown_duration"] = max_ddd
+            result_dict["summary"]["excess_max_drawdown_duration_start_date"] = str(max_ddd.start_date)
+            result_dict["summary"]["excess_max_drawdown_duration_end_date"] = str(max_ddd.end_date)
+            result_dict["summary"]["excess_max_drawdown_duration_days"] = (max_ddd.end_date - max_ddd.start_date).days
         else:
             weekly_b_returns = pandas.Series(index=weekly_returns.index)
         weekly_risk = Risk(weekly_returns, weekly_b_returns, risk_free_rate, WEEKLY)
